# July 27, 2021

**Date:** July 27, 2021, at 8am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2021-07-27/8:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)** 

**[YouTube Link](https://youtu.be/ebUXrmRfkM8)**

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

* **Michael Milligan** For cluster/scheduler users, [batchspawner](https://pypi.org/project/batchspawner/) and related [wrapspawner](https://pypi.org/project/wrapspawner/) had new releases recently
* **Steve** JupyterLab 3.1 release
* **Rick** Globus Groups support in OAuthenticator
* **Simon** mybinder.org no longer blocking public cloud requests (Resolves [this issue](https://github.com/jupyterhub/mybinder.org-deploy/issues/1828).)
* **Nick** [jupyter-videochat](https://github.com/jupyterlab-contrib/jupyter-videochat/tree/develop) 0.6.0 release is coming up, adds support for JupyterLite and RetroLab (needs config :blush:)
* **Nick** [`jupyterlite 0.1.0a6`](https://github.com/jupyterlite/jupyterlite/releases/tag/v0.1.0a6) is out, with some improved support for python kernel parity and deploying in-development lab extensions

## Agenda Items

* **Matthias** would like to talk about kernel management and parametrisation.
    * You can have a look at [prototype/in progress repo](https://github.com/Quansight/ksmm) – in need of a better name
    * I'll point out the work of [Eric Charles and Kevin Bates as well](https://github.com/jupyter/jupyter_client/pull/612#issuecomment-886686237).
* **Matthias** For cluster/scheduler user, show [inplace_restarter](https://pypi.org/project/inplace_restarter/),.
* **Rick** & **Rollin** discuss Jupyter Security [Best Practices Community Workshop old thread](https://discourse.jupyter.org/t/jupyter-security-best-practices-workshop/1496) and [new thread](https://discourse.jupyter.org/t/jupyter-security-workshop-progress/9370)
    * **Matthias** Better process for CVE. We'll have two soon. How do we coordinate release, response and co. 
* **David** would like to present a new [asynchronous Python Jupyter kernel](https://github.com/davidbrochart/akernel).

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- https://github.com/deathbeds/hourhaus - beefy binder with rtc and jupyter-videochat
- [Textual](https://github.com/willmcgugan/textual)
- [Jupyter community calendar](https://jupyter.readthedocs.io/en/latest/community/content-community.html#jupyter-community-meetings)
- [Enarx](https://github.com/enarx/enarx)
- [NSF Secure and Trustworthy Cyberspace](https://www.nsf.gov/funding/pgm_summ.jsp?pims_id=504709)
- [Jupyter Security Best Practices Workshop (2019)](https://discourse.jupyter.org/t/jupyter-security-best-practices-workshop/1496)
- [Jupyter Security Workshop Progress 2021](https://discourse.jupyter.org/t/jupyter-security-workshop-progress/9370)
- [Google Bug Hunters](https://bughunters.google.com/about/patch-rewards)
- [Eager Award](https://www.nsf.gov/pubs/policydocs/pappguide/nsf09_1/gpg_2.jsp#IID2)
- [ipydrawio](https://github.com/deathbeds/ipydrawio)
- [Exploring and defining UX expectations for a RTC enabled multi-user environment (like JupyterHub)](https://github.com/jupyterlab/jupyterlab/issues/10119)
- [rtc in jupyterlite](https://github.com/jupyterlite/jupyterlite/blob/d0aafc4a697a814c21f9412546a20e1b36ad4e0f/packages/application-extension/src/index.tsx#L44)
- [hedgedoc vs yjs (hackmd is the SaaS hedgedoc)](https://github.com/hedgedoc/hedgedoc/issues/527)

## Attendees

If you are joining the Jupyter Community Call, sign in below so we know who was here.

|   Name   |           Institution     | GitHub Handle      |
|----------|---------------------------|--------------------|
| Matthias |Quansight/Jupyter          | @Carreau
| Thorin   |UCSD                       | @tmtabor
| Anton    |TU Delft                   | @akhmerov
| David    |QuantStack                 | @davidbrochart
| Michael  | University of Minnesota   | @mbmilligan
| Rick     | UCSD                      | @rpwagner
| Nick     | Georgia Tech              | @nrbgt @bollwyvl
| Wayne Decatur | Upstate Medical University | @fomightez |
| Simon Li | University of Dundee      | @manics |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |
| Tony Fast | Quansight                | @tonyfast |

Plus 9 others